COGNITO_ATTRIBUTE = 'custom:last_name'
RDS_TABLE_COLUMN = 'last_name'
QUERY_STRING = f'SELECT user_id, {RDS_TABLE_COLUMN} FROM app_users WHERE org_id != 0 LIMIT 5'
REGION = 'us-east-1'
FOLDER_NAME = 'files'



import time
import datetime
import csv
import sys
import os

from RDS_Cognito_attribute_alignment.rds_cognito_pkg.models import User
from RDS_Cognito_attribute_alignment.rds_cognito_pkg.functions import get_db_data, connect_to_db
from RDS_Cognito_attribute_alignment.rds_cognito_pkg.settings import RDS_TABLE_COLUMN, COGNITO_ATTRIBUTE, FOLDER_NAME


# This variable will hold your RDS connection object which will be used later in the script.
my_connection = connect_to_db(
    db_user='app',
    db_password='Sd#smXXaKraQLQ7r7b',
    db_host='povprdbp01.cu3hu9sx5vpk.us-east-1.rds.amazonaws.com',
    db_port='3306',
    db_database='vpcdbp01')


# Create a variable to hold your user information and call the get_db_data function using the my_connection variable.
user_list = get_db_data(my_connection)
evaluated_user_list = []
user_count = 0

# Loop through all the users returned from the DB and add their data to the evaluated_user_list
for user in user_list:
    time.sleep(.75)
    user_count += 1
    new_user = User(user[0], user[1])
    new_user.get_cognito_attr_value()

    user_dict = {}

    user_dict['user_id'] = new_user.user_id
    user_dict[RDS_TABLE_COLUMN] = new_user.rds_value
    user_dict[COGNITO_ATTRIBUTE] = new_user.cognito_value
    user_dict['evaluation'] = new_user.rds_cognito_match()

    evaluated_user_list.append(user_dict)

    sys.stdout.write(f'\rUsers processed: {user_count}')
    sys.stdout.flush()

report_name = f'{RDS_TABLE_COLUMN}_{datetime.datetime.now()}.csv'

print(f'\nCreating {report_name}')

if not os.path.exists(FOLDER_NAME):
    os.makedirs(FOLDER_NAME)

with open(os.path.join(FOLDER_NAME, report_name), 'w', newline='') as report:

    fieldnames = [
        'user_id',
        RDS_TABLE_COLUMN,
        COGNITO_ATTRIBUTE,
        'evaluation'
    ]
    writer = csv.DictWriter(report, fieldnames=fieldnames)

    writer.writeheader()
    for data in evaluated_user_list:
        writer.writerow(data)

print(f'\nProcess Complete!')



import mysql.connector

from RDS_Cognito_attribute_alignment.rds_cognito_pkg.settings import QUERY_STRING


def connect_to_db(db_user, db_password, db_host, db_port, db_database):
    """
    Use this function to connect to your RDS instance
    """
    print('Connecting to DB')
    connection = mysql.connector.connect(
        user=db_user,
        password=db_password,
        host=db_host,
        port=db_port,
        database=db_database
    )
    return connection


def get_db_data(conn):
    """
    This function will take the connection object returned by the connect_to_db function and gather
    the required attribute data from your RDS instance.
    """
    db_data = []

    cursor = conn.cursor()

    # Set this variable to the query you intend to execute in your RDS instance.
    # query = f'SELECT user_id, {rds_table_column} FROM app_users WHERE org_id != 0 LIMIT 5'

    cursor.execute(QUERY_STRING)

    for (user_id, org_id) in cursor:
        db_data.append([user_id, org_id])

    conn.close()
    return db_data


import boto3
from RDS_Cognito_attribute_alignment.rds_cognito_pkg.settings import COGNITO_ATTRIBUTE

client = boto3.client('cognito-idp', region_name=region)


class User:
    """
    This class defines an actual user.
    """
    user_pool_id = 'us-east-1_Hx4y8Olmh'

    def __init__(self, user_id, rds_value):
        self.user_id = user_id
        self.rds_value = rds_value
        self.cognito_value = ''

    def get_cognito_attr_value(self):
        """
        Use this function to connect to Cognito and retrieve a specific user attribute value.
        """
        response = client.admin_get_user(
            UserPoolId=self.user_pool_id,
            Username=self.user_id
        )
        user_attributes = response['UserAttributes']

        for attribute in user_attributes:
            if attribute['Name'] == COGNITO_ATTRIBUTE:
                self.cognito_value = attribute['Value']

    def rds_cognito_match(self):
        """
        Use this function to verify whether or not RDS and Cognito attribute values match
        """
        return str(self.rds_value) == str(self.cognito_value)